@@ -1,6 +1,6 @@
 ;;; (oauth oauth1 signature) --- Guile OAuth 1.0 implementation.
 
-;; Copyright (C) 2013, 2014 Aleix Conchillo Flaque <aconchillo@gmail.com>
+;; Copyright (C) 2013-2018 Aleix Conchillo Flaque <aconchillo@gmail.com>
 ;;
 ;; This file is part of guile-oauth.
 ;;
@@ -30,8 +30,8 @@
   #:use-module (rnrs bytevectors)
   #:use-module (srfi srfi-9)
   #:use-module (web uri)
-  #:use-module (weinholt crypto sha-1)
-  #:use-module (weinholt text base64)
+  #:use-module (oauth hashing sha-1)
+  #:use-module (oauth industria base64)
   #:export (oauth1-signature
             oauth1-signature?
             oauth1-signature-method
@@ -78,3 +78,5 @@
    "PLAINTEXT"
    (lambda (base-string credentials token)
      (uri-encode (plaintext-signature credentials token)))))
+
+;;; (oauth oauth1 signature) ends here
