@@ -1,6 +1,6 @@
 ;;; (oauth oauth1 utils) --- Guile OAuth 1.0 implementation.
 
-;; Copyright (C) 2013, 2014 Aleix Conchillo Flaque <aconchillo@gmail.com>
+;; Copyright (C) 2013-2018 Aleix Conchillo Flaque <aconchillo@gmail.com>
 ;;
 ;; This file is part of guile-oauth.
 ;;
@@ -26,20 +26,16 @@
 ;;; Code:
 
 (define-module (oauth oauth1 utils)
-  #:use-module (gnutls)
-  #:use-module (ice-9 binary-ports)
-  #:use-module (ice-9 receive)
-  #:use-module (rnrs bytevectors)
+  #:use-module (ice-9 format)
+  #:use-module (ice-9 match)
   #:use-module (srfi srfi-19)
-  #:use-module (web client)
   #:use-module (web uri)
   #:export (oauth1-timestamp
             oauth1-nonce
+            oauth1-param?
             oauth1-normalized-params
             oauth1-normalized-header-params
-            oauth1-parse-www-form-urlencoded
-            oauth1-http-get
-            oauth1-http-post))
+            oauth1-parse-www-form-urlencoded))
 
 (define (oauth1-timestamp)
   "Return the number of seconds since the epoch, 00:00:00 UTC on 1
@@ -50,19 +46,29 @@ January 1970."
   "A random string"
   (date->string (current-date) "~s"))
 
+(define (oauth1-param? param)
+  "Returns true if this parameter pair is used by OAuth, and false
+otherwise.  Useful when filtering parameter lists."
+  (match param
+    ((k . v)
+     (string-prefix-ci? "oauth_" (if (symbol? k) (symbol->string k) k)))))
+
 (define (encode-and-sort-params params)
   (stable-sort
-   (map
-      (lambda (pair) (cons (uri-encode (symbol->string (car pair)))
-                           (uri-encode (cdr pair))))
-      (assq-remove! params 'oauth_signature))
-   (lambda (a b)
+   (let lp ((params params))
+     (match params
+       (() '())
+       ((('oauth_signature . _) . params) (lp params))
+       (((key . value) . params)
+        (acons (uri-encode (symbol->string key)) (uri-encode value) (lp params)))))
+   (match-lambda*
+    (((k1 . v1) (k2 . v2))
      (cond
       ;; If it's less, simply return true
-      ((string< (car a) (car b)) #t)
+      ((string< k1 k2) #t)
       ;; If it's equal, compare value
-      ((string= (car a) (car b)) (string< (cdr a) (cdr b)))
-      (else #f)))))
+      ((string= k1 k2) (string< v1 v2))
+      (else #f))))))
 
 (define (oauth1-normalized-params params)
   "Returns a normalized single string for the given @var{params}
@@ -97,54 +103,4 @@ strings."
            (cons (uri-decode piece #:encoding charset) ""))))
    (string-split str #\&)))
 
-;;
-;; HTTP/HTTPS methods
-;;
-
-(define (https-call https-proc)
-  (lambda* (uri #:key (headers '()))
-    (let* ((socket (open-socket-for-uri uri))
-           (session (make-session connection-end/client)))
-      ;; (set-log-level! 9)
-      ;; (set-log-procedure!
-      ;;  (lambda (level msg) (format #t "|<~d>| ~a" level msg)))
-
-      ;; Use the file descriptor that underlies SOCKET.
-      (set-session-transport-fd! session (fileno socket))
-
-      ;; Use the default settings.
-      (set-session-priorities! session "NORMAL")
-
-      ;; Create anonymous credentials.
-      (set-session-credentials! session
-                                (make-anonymous-client-credentials))
-      (set-session-credentials! session
-                                (make-certificate-credentials))
-
-      ;; Perform the TLS handshake with the server.
-      (handshake session)
-
-      (receive (response body)
-          (https-proc uri
-                     #:port (session-record-port session)
-                     #:keep-alive? #t
-                     #:headers headers)
-        (bye session close-request/rdwr)
-        (values response body)))))
-
-(define https-get (https-call http-get))
-(define https-post (https-call http-post))
-
-(define* (oauth1-http-get uri headers)
-  "Perform an HTTP GET request with the given HTTP @var{headers} to the
-@var{uri}."
-  (if (eq? (uri-scheme uri) 'http)
-      (http-get uri #:headers headers)
-      (https-get uri #:headers headers)))
-
-(define* (oauth1-http-post uri headers)
-  "Perform an HTTP POST request with the given HTTP @var{headers} to the
-@var{uri}."
-  (if (eq? (uri-scheme uri) 'http)
-      (http-post uri #:headers headers)
-      (https-post uri #:headers headers)))
+;;; (oauth oauth1 utils) ends here
